package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````X"5```````!``````````#"S````
M`````````$``.``-`$``'``;``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````#@:````````.!H`````````
M$`````````$````%`````"``````````($`````````@0```````S3T`````
M``#-/0`````````0`````````0````0`````8`````````!@0````````&!`
M``````"H10```````*A%`````````!`````````!````!@```&"M````````
M8+U```````!@O4```````)@$````````Z!0`````````$`````````(````&
M````<*T```````!PO4```````'"]0```````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#0```````.`-```````!`````````
M`$``````````"``````````$````!````'@#````````>`-```````!X`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````0`````````!```````````@`````````4.5T9`0`
M``!`GP```````$"?0```````0)]```````#4`````````-0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````8*T```````!@O4```````&"]0```
M````H`(```````"@`@````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`'Q[^<;4LLS$!-2CHX!W[_XS:B*4!````!`````!````1TY5```````#
M`````@``````````````$0```$@````"````!P```)J5@``)8!1("(X408J$
M`.@`````2````$L```!.````3P```%4```!6````5P````````!9````````
M`%H```!;````7````%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K"4/69Z_,9D)%U>R)
M!W#3,V+;[0TZEPM_J9R;X:<""J/@^TD`````````````````````````````
M````````!`$``!(`````````````````````````E@```!(`````````````
M````````````+P(``!(`````````````````````````I@(``!(`````````
M````````````````ZP(``!$`````````````````````````BP$``!(`````
M````````````````````F`(``!(`````````````````````````:0(``!(`
M````````````````````````&@$``!(``````````````````````````0``
M`"``````````````````````````Q0$``!(`````````````````````````
M\P(``!(`````````````````````````%@(``!(`````````````````````
M````X0(``!(`````````````````````````H@$``!(`````````````````
M````````2P$``!(`````````````````````````MP```!(`````````````
M````````````.P$``!(`````````````````````````\P$``!(`````````
M````````````````$`(``!(`````````````````````````+0$``!(`````
M````````````````````&P(``!(`````````````````````````0P(``!(`
M````````````````````````Z0(``!$`````````````````````````TP,`
M`!(`````````````````````````$````"``````````````````````````
MJ0$``!(`````````````````````````"0$``!(`````````````````````
M````"0(``!(`````````````````````````+````"``````````````````
M````````>`(``!(`````````````````````````K`(``!(`````````````
M````````````1@```!(`````````````````````````8P```!8`````````
M````````````````>P$``!(`````````````````````````=@```!(`````
M````````````````````!0,``!(`````````````````````````\P```!(`
M````````````````````````AP```!(`````````````````````````[`$`
M`!(`````````````````````````*`(``!(`````````````````````````
MUP```!(`````````````````````````2@(``!(`````````````````````
M````;0$``!(`````````````````````````^@$``!(`````````````````
M````````GP(``!(`````````````````````````7P$``!(`````````````
M````````````T`(``!(`````````````````````````W`$``!(`````````
M````````````````#@$``!(`````````````````````````M`$``!(`````
M````````````````````R0(``!(``````````````````````````@(``!(`
M````````````````````````=P(``!(`````````````````````````M`(`
M`!(`````````````````````````H@```!(`````````````````````````
ME@$``!(`````````````````````````R@$``!(`````````````````````
M````XP$``!(`````````````````````````6P(``!(`````````````````
M````````D0(``!$`````````````````````````Y@```!$`````````````
M````````````NP(``!(`````````````````````````4P(``!(`````````
M````````````````5`$``!(`````````````````````````5````!(`````
M````````````````````?P(``!(`````````````````````````P@(``!(`
M````````````````````````T@$``!(`````````````````````````/0(`
M`!(`````````````````````````Q0```!(`````````````````````````
MW`,``!(`#@!074```````%\`````````'00``!(`#@!@3D```````#@+````
M````C`(``!(`#@#@(T`````````"````````70,``!(`#@!`1$````````4`
M````````>P,``!(`#@"@64```````*<#````````0P0``!(`#@!01$``````
M`/(!````````#`0``!``&0#XP4``````````````````;@,``!(`#@!01D``
M`````"4`````````D0,``!(`#@"P3$```````'0`````````Z`,``!$`$```
M8$````````0`````````!`0``!(`#@``0T```````#4`````````&`0``!``
M&0!(TD``````````````````,00``!(`#@!034````````L!````````]P,`
M`!``&`#8P4``````````````````M0,``!(`#@"`1D```````-P`````````
M*@0``!``&`#XP4``````````````````4`0``!$`&`#PP4````````@`````
M````_0,``!(`#@#@)4```````"8`````````^0,``"``&`#8P4``````````
M````````P0,``!(`#@`P34```````!T`````````GP,``!(`#@"`0T``````
M`+\`````````6@0``!(`#@!@1T```````$8%`````````%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?
M8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S
M:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E
M:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'5N;&EN:P!M
M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`
M<W1R<W1R`%]?<W1R;F-P>5]C:&L`;6MD:7(`9V5T<&ED`')E861L:6YK`')E
M86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L
M:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!S=')C:'(`8VQO<V4`;W!E
M;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A
M=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W1L
M<U]G971?861D<@!L:6)P97)L+G-O+C4N,S8N,`!L:6)M+G-O+C8`;&EB8RYS
M;RXV`&QD+6QI;G5X+7@X-BTV-"YS;RXR`&QI8F-R>7!T+G-O+C$`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?8G-S7W-T87)T
M`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,`
M1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,
M24)#7S(N,RXR`$=,24)#7S(N,BXU`$=,24)#7S(N,RXT`"]U<W(O;&EB-C0O
M<&5R;#4O-2XS-BXP+W@X-E\V-"UP;&0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4``````0`!``(``P`#``$``P`"``$``0`#``0``P`#``,``0`!``$``P`#
M``$``@`#``,``P`!``$``P`#``$`!0`#``$``0`!``$`!@`!``$``P`#``$`
M`P`!``,``P`!``,``P`!``<``P`#``4``P`!``$``P`#``(``P`!``,``P`!
M``$`"``)``,``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!`#H#```0````(````!-I:0T```8`9P0````````!
M``<`,`,``!``````````E)&6!@``"0!Q!```$````+21E@8```@`?`0``!``
M```4:6D-```'`(<$```0````LY&6!@``!0"1!```$````'(9:0D```0`G`0`
M`!````!U&FD)```#`*@$```0````=!EI"0```@"T!````````)"_0```````
M!@````4``````````````)B_0```````!@````D``````````````*"_0```
M````!@````H``````````````*B_0```````!@```!H``````````````+"_
M0```````!@```!X``````````````+B_0```````$@```"(`````````````
M`,"_0```````!@```",``````````````,B_0```````!@```"0`````````
M`````-"_0```````!@```#T``````````````-B_0```````!@```#X`````
M`````````."_0```````!@```$,```````````````#`0```````!P````$`
M``````````````C`0```````!P````(``````````````!#`0```````!P``
M``,``````````````!C`0```````!P````0``````````````"#`0```````
M!P````8``````````````"C`0```````!P````<``````````````##`0```
M````!P````@``````````````#C`0```````!P````L``````````````$#`
M0```````!P````P``````````````$C`0```````!P````T`````````````
M`%#`0```````!P````X``````````````%C`0```````!P````\`````````
M`````&#`0```````!P```!```````````````&C`0```````!P```!$`````
M`````````'#`0```````!P```!(``````````````'C`0```````!P```!,`
M`````````````(#`0```````!P```!0``````````````(C`0```````!P``
M`!4``````````````)#`0```````!P```!8``````````````)C`0```````
M!P```!<``````````````*#`0```````!P```!D``````````````*C`0```
M````!P```!L``````````````+#`0```````!P```!P``````````````+C`
M0```````!P```!T``````````````,#`0```````!P```!\`````````````
M`,C`0```````!P```"```````````````-#`0```````!P```"$`````````
M`````-C`0```````!P```"4``````````````.#`0```````!P```"8`````
M`````````.C`0```````!P```"<``````````````/#`0```````!P```"@`
M`````````````/C`0```````!P```"D```````````````#!0```````!P``
M`"H```````````````C!0```````!P```"L``````````````!#!0```````
M!P```"P``````````````!C!0```````!P```"T``````````````"#!0```
M````!P```"X``````````````"C!0```````!P```"\``````````````##!
M0```````!P```#```````````````#C!0```````!P```#$`````````````
M`$#!0```````!P```#(``````````````$C!0```````!P```#,`````````
M`````%#!0```````!P```#0``````````````%C!0```````!P```#4`````
M`````````&#!0```````!P```#8``````````````&C!0```````!P```#<`
M`````````````'#!0```````!P```#@``````````````'C!0```````!P``
M`#D``````````````(#!0```````!P```#H``````````````(C!0```````
M!P```#L``````````````)#!0```````!P```#P``````````````)C!0```
M````!P```#\``````````````*#!0```````!P```$```````````````*C!
M0```````!P```$$``````````````+#!0```````!P```$(`````````````
M`+C!0```````!P```$0``````````````,#!0```````!P```$4`````````
M`````,C!0```````!P```$8``````````````-#!0```````!P```$<`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!9&?``!(A<!T`O_02(/$",,``````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M__\E"IX``&@X````Z6#\____)0*>``!H.0```.E0_/___R7ZG0``:#H```#I
M0/S__T%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E
M*````$B)1"0H,<#H=____TB+-7B;``!(BSVAFP``2(GRZ($Y``!(BP6BFP``
M@#@`=3?H0/W__TB)!?FM``!(B<=(A<`/A(,!``#HJ/W__V1(BP0E`````$@#
M!5";``!(BP#&@-<)````9$B+!"4`````2`,%-IL``$B+`("(*@0```.+1"0<
MC7@%2&/_2,'G`^B!_O__3(M$)!!,8TPD',<%?:T```0```!(B<%(B05KK0``
MO@$```!)BP!,B<I(B0%(C07V/```2(E!"$C'P/#!0`!(BP!(B4$02(T%X#P`
M`$B)01A!@_D!?AH/'P!)BP3PC7X#2(/&`4AC_TB)!/E).?%UZ8/"`TB+/2>M
M``!%,<!(C34='@``2&/"2,<$P0````#H/?O__T&)Q(7`=%-(BSW_K```2(UL
M)"3H-?W__S'`2(GN2(T]3#L``.BD%P``2(7`=#U(BSW8K```Z,/Z___H7OS_
M_TB+1"0H9$@K!"4H````=4](@\0X1(G@74%<PTB+/:RL``#H5_O__T&)Q.N<
M2(L]DZP``$B%_W0'Z*$W``#KL$B-/:`Z``!(B>[H0!<``$B)!7&L``!(B<=(
MA<!TDNO9Z.K\__^_`0```.C`^O__\P\>^C'M28G17DB)XDB#Y/!05$4QP#')
M2,?'X"-``/\5VYD``/1F+@\?A```````\P\>^L-F+@\?A```````D$B-/=&;
M``!(C07*FP``2#GX=!5(BP5NF0``2(7`=`G_X`\?@`````###Q^``````$B-
M/:&;``!(C36:FP``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!369``!(A<!T
M"/_@9@\?1```PP\?@`````#S#Q[Z@#UEFP```'4354B)Y>AZ____Q@53FP``
M`5W#D,-F9BX/'X0```````\?0`#S#Q[ZZXIF+@\?A```````05=(B?Y,C4\X
M059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-E"2`````
M28G0#Q^``````$&+`4F+.4F#P!!)@\$(#\B)P$B)^4F)0/!(B?A(P>D@2,'H
M*$C![S@E`/\``$@)^$B)STC!X0A(P><8@>$``/\`B?]("?A("<A)B4#X33G0
M=:Y(C;H``@``#Q^``````$B+0FA(,T)`2(/""$@S0@A(,T+X2(T,`$C!Z!](
M"<B#X/](B4)X2#GZ==5,BPY,BUX02(M^($B+7AA,B<A,B<I(BVX(2(M,)`A(
MP>H;2,'@!4@)T`,$)$B-C`N9>8):C90XF7F"6DR)V$@QV$@AZ$@QV(T\`DB)
MZDB)Z$C!Z`)(P>(>28GZ2`G"3(G82<'J&T&)T$PQP$PAR$PQV$@!R$B)^4C!
MX05,"=%,BU0D$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):38GE2`G(2<'M
M&T@QPHG!2"'Z3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GZ2,'O`DC!XAY%
MB=)/C80HF7F"6D@)^DV)U4@QT(G73"'@2<'M&T@QR$P!P$V)T$G!X`5-">A,
MBVPD($$!P$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$
M3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B'HG)2HV\+YEY
M@EI,"=))B<U(,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)[TR+;"0P`<=,
MB<!)P>@"2,'@'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B
M28G\2<'D!4T)[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90JF7F"6D@)RDV)
MY4@QT$G![1N)T4@A^$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!PDB)^$C![P)(
MP>`>18G23XV$*)EY@EI("?A-B=5(,<))P>T;B<=,(>)(,<I,`<)-B=!)P>`%
M30GH3(ML)$A!`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB38G%2#'02<'M
M&T&)U$PAT$@Q^$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J`DC!X!Z)R4J-
MO"^9>8):3`G028G-2#'"2<'M&T&)PDPAPDPQXD@!^DB)STC!YP5,">],BVPD
M6`'73(G"2<'H`DC!XAZ)_T^-I"R9>8):3`G"28G]2#'02<'M&T&)T$@AR$PQ
MT$P!X$F)_$G!Y`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD3XV4*IEY@EI(
M"<A-B>5(,<))P>T;B<%((?I,,<),`=)-B>))P>(%30GJ3(ML)&A!`=)(B?I(
MP>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'02<'M&XG73"'@2#'(3`'`38G0
M2<'@!4T)Z$R+;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@Q
MPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)'@!T4R)TDC!XAY)P>H"
MB<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO
M3(NL)(`````!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!
MB<!((<I,,=),`>))B?Q)P>0%30GL1HTL(DB)RDC!Z0),BZ0DB````$C!XAY(
M"<I/C90BF7F"6DV)[$@QT$G![!N)T4@A^$PQP$P!T$V)ZDG!X@5-">),BZ0D
MD````$$!PDB)^$C!X!Y(P>\"18G23XV$()EY@EI("?A-B=1(,<))P>P;B<=,
M(>I(,<I,`<)-B=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!B=1-">A,BZPD
MF````$PQP$PAT$J-C"F9>8):38GE2#'X2<'M&T@!R$R)X4C!X05,">F)R4@!
MR$R)T4G!Z@)(P>$>08G%3`G138G"18G`23'*1#'23(N4)*````!*C;P7H>O9
M;DV)ZD@!UTR)ZDG!ZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L`D&)^DP#A"2H
M````3`GB28G,B<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!
MX`5,"<")P$D!Q$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0DN````$DQQ40Q
M[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO
M3`G128G"B<!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,
MB<))P>@"2,'B'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPDR````$4QZ$Z-
MK`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX
M2(G7B=)(`Y0DT````$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0DV````$DQRD4QZDZ-K!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(
MB<E),=!(`XPDX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!
MQ$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0DZ````$@QQT0Q[TR-K#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(
M`X0D\````$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)
MPDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)
MP>@;2`.,)/@```!,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D
M``$``$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!
MZ@)(P>$>1(GG3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.
MC:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!Q$B)^$C![P)(
MP>`>18G@2`GX2(G7B=)(`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D(`$``$DQ
MRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>
M18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<5(B?A(P>`>2,'O`D6)Z$@#C"0H`0``2`GX2(G7B=)(`Y0D,`$``$@QQT0Q
MYTV)Q$B-C#FAZ]EN3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D'HG_30G428G"
M2`'YB<!-,>*)ST@#A"0X`0``13'J28G]3HV4$J'KV6Y(B?I)P>T;2,'B!4P)
MZD$!TDR)PDG!Z`)(P>(>18G23`G"38G@18GD23'028G608G51#'!38G02(V,
M"*'KV6Y,B=!)P>@;2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](P>$>2`GY20G.
MB<]((?I-(=9)"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT
M00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D2`$`
M`$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%
MB>U,"<%!B<A)"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]TV)[D@!^DR)[TG!
M[AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ
M3(NT)%@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G!
M[0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)&`!``!)`<9-`?!-B=9,
M`<)-B=!)P>`%2<'N&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-
M(>Y,(=%,"?%,B[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G6
M00',3(G12<'J`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D<`$``$D!
MQDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)(
M"=%)B=9!B=!-(=9,(>%,"?%,B[0D>`$``$D!QDP!]TV)[D@!^4R)[TG![AM(
MP><%3`GW28G6`<],B>%)P>P"2,'A'HG_3`GA08G,20G.32'N3"'B3`GR3(NT
M)(`!``!)`<9-`?))B?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>
M18G23`GJ2`G128G608G52"'Y32'F3`GQ3(NT)(@!``!)`<9-`?!-B=9,`<%-
MB=!)P>X;2<'@!4T)\$F)UD$!R$B)^4C![P)(P>$>18G`2`GYB<])"<Y-(=9(
M(?I,"?),B[0DD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G2
M2<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0DF`$``$D!QDT!
M]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!
MB<A)"<Y-(>9,(<),"?),B[0DH`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%
M3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)*@!
M``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>
M18G23`GI08G-20G.22'^3"'J3`GR3(NT)+`!``!)`<9-`?!-B=9,`<)-B=!)
MP>X;2<'@!4T)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,
M"?%,B[0DN`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G1
M2<'J`DC!X1Y%B>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$``$D!QDT!]4V)
MYDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!
MB==-(=!,(>%,"<%,BX0DR`$``$D!P$P!QTV)Z$@!^4R)[TG!Z!M(P><%3`G'
M1(T$.4R)YTG![`)(B=%(P><>3`GG08G\2`GY3"'I3"'B2`G*2(N,)-`!``!(
M`<%,`=%-B<)(`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(`<I,B>E)P>T"
M2,'A'D&)TDP)Z4@)STF)S4&)SDPAQTTAY4D)_4J-/#A,B=!,B[PD^`$``$P!
M[TV)U4C!X`5)P>T;3`GHB<!(`<=,B<!)P>@"2,'@'D&)_4D)P+C6P6+*3#'!
M,=%(BY0DX`$``$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA38G4B<E)P>0>
M2`'*2<'J`DD!QTT)XDV)Q(G118G`33'41#'G3(ND).@!``!)`<1-`?1)B<Y,
M`>=)B<Q)P>X;2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT)/`!``!,`>=!
MB?Q)`<9-`?!-B=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)\HG220'02(G*
M2,'I`DC!XAY%B<9("<I$B=%-B>I),=),`?E,B[PD``(``$0QUTV)\D@!STR)
M\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G2
M33'E3`'Y3(N\)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A!4P)Z8G)20'(
M3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQSD0Q]TV)[D@!
MUTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TD2)XDF)S(G)
M3`'Z33'43(N\)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B!4P)XHG220'0
M3(GJ2<'M`DC!XAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQU40Q[TV)Y4@!
MSTR)X4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG2
M33'R3`'Y3(N\)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)T8G)20'(3(GA
M2,'A'DG![`)%B<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQS$0QYTV)U$@!
MUTR)TDG![!M(P>(%3`GBB=)(`==,B>I)P>T"2,'B'D&)_$D)U42)\DF)SHG)
M33'N3`'Z3(N\)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)\HG220'03(G2
M2<'J`DC!XAY%B<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0QUTV)\D@!STR)
M\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G2
M33'E3`'Y3(N\)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)Z8G)20'(3(GQ
M2<'N`DC!X1Y%B<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQSD0Q]TV)[D@!
MUTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TDB+E"10`@``
M2`'"20'42(G*B<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B!4P)PHG220'4
M3(GJ2<'M`DC!XAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQU40Q[TV)Q4@!
MSTR)P4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG2
M33'R3`'Y3(N\)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)XDV)Q$6)TDG!
MY!Y,`=%)P>@"20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(``$P!XDV)]$P!
MR$TQQ$0QYTV)U$@!UTR)TDG![!M(P>(%3`GB38GL2<'M`DG!Y!Z)TDT)Y46)
M]$V)QD@!UTTQ[HGZ30'\18G`1#'Q28G63`'`38GH3`'A28G42<'N&TG!Y`5-
M"?1$`>%-B=1)P>H"2<'D'HG)30GB33'01#''28G(2`'X2(G/2,'G!4G!Z!L!
MZ4$!VDP)QT0#;B!(B4X(`?A,B5882(D&2(G02,'J`DC!X!Y,B6X@2`G01`'8
M2(E&$$B+A"2(`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/HP.7_
M_T%7059!54%455-(@^P(2(7_#X2Q````2(L%<H(``$R+*$V%[0^$G@````^V
M!TF)_TB)]83`=`0\/75513'V38ME`$V%Y'0O36/V3(GK#Q\`3(GR3(G^3(GG
MZ'+C__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=05Y!
M7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY4/'X``````3"GK
M3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%505154TB![*````!D
M2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K!"4H
M````#X4A`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HB^/__TF)Q$B%
MP'3"3(TMP"$``$R)Y^ADY?__2(7`#X2C````@'@3+DB-6!-U"8![`0!TWP\?
M`(!X$RX/A)X```!(B>_H)N/__TB)WTF)QN@;X___08U\!@)(8__H3N+__TF)
MV4F)Z$R)Z4F)QDB)Q[X!````,<!(Q\+_____Z)SD__],B?=(B>;H\>+__TR)
M]X/X_W00BT0D&"4`\```/0!```!T6>A$XO__3(GWZ*SB__],B>?HQ.3__TB%
MP`^%8/___P\?`$R)Y^A`Y/__2(GOZ"CB___I\O[__P\?`(![`2X/A5C___^`
M>P(`#X0@____Z4G___\/'X``````Z)O^___KI>B$X___#Q]``%5(B?U(@>R@
M````9$B+!"4H````2(F$))@````QP$B)YNB*X___A<!U-HM4)!B!X@#P``"!
M^@!```!T"('Z`*```'4>O@(```!(B>_HS^/__X7`#Y3`#[;`ZP</'T0``#'`
M2(N4))@```!D2"L4)2@```!U"4B!Q*````!=P^C]XO__9F8N#Q^$``````!F
MD$%6NO\/``!!54%428GT54B)_4B-/2$@``!(@>P8$```9$B+!"4H````2(F$
M)`@0```QP$F)Y4R)[N@RXO__A<!^3HU0_TQC\D*`/#0`#X5]````A=)T.4R)
M\KXO````3(GOZ$G@__](A<!T)&1(BP0E`````$@#!6Q_``!,B?%,B>I(B>Y(
MBSCHT^'__^L?D&1(BP0E`````$@#!4A_``!,B>)(B>Y(BSCHPN#__TB+A"0(
M$```9$@K!"4H````=1=(@<08$```74%<05U!7L-,8_#I?____^@3XO__#Q\`
M05=!5D%505152(GU4TB)^TB#["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(
M`<5(B>_HN>#__TB-="042(G?28G$,<#H!_S__TB%P`^$!@$``$B)QTF)Q>B3
MX/__23G$#X;2````2&-,)!1,BS5N?@``3(T\S0`````/M@.$P`^$HP$``#P]
M#X2;`0``2(G8#[90`4B#P`&$TG0%@/H]=>](*=A(F$V++DJ-?"`"Z'W?__]-
M`?U)B44`2(7`=%))BP9(C4L!2HL4.`^V`X@"A,!T(CP]=0WK'`\?@`````"$
MP'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$
MR77O2(M$)!AD2"L$)2@````/A1<!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F
M#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,BS6!?0``38L&28,X``^$
MPP```$R)P$4Q[68/'T0``$B#P`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%
MUX\``(7`=6-(B?=,B40D",<%P8\```$```#H?-[__TB)QTB%P`^$4?___TEC
MS4B+="0(3(T\S0````!,B?KHV-___TF)!DB)QT&-10%$B6PD%$B82,<$QP``
M``#IA/[__V8N#Q^$``````!,B<?HN.#__TF)!DB)QTB%P`^$^O[__TECS4R-
M/,T`````Z[H/'T``,<#I=_[__[X0````13'MZ5?____HS]___V9F+@\?A```
M````#Q]``$B#[`AD2(L$)0````!(`P6D?```2(L5I7P``$B-#>Y;``!(C37P
M'```2(LX2(/$".E+X/__9F8N#Q^$``````!39$B+!"4`````2`,%9WP``$B+
M.$B)P^BD____2(L[3(T%/QX``%M(Q\*@64``13')3(G!2(TUNAP``.EPWO__
M05154TB!["`@``!D2(L$)2@```!(B80D&"```#'`2(GE3(VD)!`0``#HLMW_
M_TR-#6`<``"Z`1```$B)[T&)P$B-#8,<``"^`0```#'`Z'W?__^Z`!```$R)
MYDB)[^A=WO__13'`A<!X+HUX`4B)PTAC_^CHW/__28G`2(7`=!A(8]M,B>9(
MB<=(B=KHC]___\8$&`!)B<!(BX0D&"```&1(*P0E*````'4/2('$("```$R)
MP%M=05S#Z('>__^0Z3O___]F9BX/'X0``````$%7059)B?9!54%454B)_4B-
M/?(;``!32('LR!```&1(BP0E*````$B)A"2X$```,<!(C70D'.AU^/__OB\`
M``!(B>](B</HU=W__TB%P'1`,<!(B>Y(C3VU&P``Z/_[__](B>A(BY0DN!``
M`&1(*Q0E*`````^%<@$``$B!Q,@0``!;74%<05U!7D%?PP\?`$B)[TR-)80;
M``#HL=S__TR)YDR)]T&)Q^CCW?__28G%2(7`=)M!C4<!08!]``!,C35!'```
MB40D#`^$O@```)!(A=MT$TR)[DB)W^B@W?__A<`/A(0```!,B>_H8-S__^L)
M9@\?1```Q@(`B<&#Z`%(8]!,`>J`.B]T[0-,)`R!^?\/```/CS7___],C;PD
ML````$R)\4V)Z#'`2(/L"+H`$```O@$```!,B?]53(T-W!H``.BWW?__2(UT
M)#!,B?_H"MS__UI9A<!U$(M$)#@E`/```#T`@```=%1,B>8Q_^@:W?__28G%
M2(7`#X3._O__08!]```/A4/___](A=MT!8`[+G093(TM:!H``+D!````Z6/_
M__\/'X0``````(![`0!TMNO?#Q^$``````"^`0```$R)_^A#W?__A<!UFTR)
M_DB-/38:``#H@/K__TR)_^AHW/__Z7?^___H?MS__V9F+@\?A```````#Q\`
M#[8'28GXA,!T%V8/'T0``$B#QP$\+P^V!TP/1,>$P'7O3(G`PV9F+@\?A```
M````2(7_#X3'````58`_`$B)_0^$H@```.@%V___2(U4!?](.=5R%.F;````
M9@\?1```2(/J`4@YU70E@#HO=/)(.=4/@WX```!(@^H!2#G5=`Z`.B]T*$B#
MZ@%(.=5U\H!]`"]T5$B-/849``!=Z:_;__\/'X``````@#HO=0E(@^H!2#G5
M<O)(*>HQP$B-2@)(@?D`$```=QA(@\(!N0`0``!(B>Y(C3WU>@``Z"#9__]=
MPV8/'T0``$B-/1<9``!=Z5O;__](.=5UL^N2#Q]``$B-/?\8``#I1-O__P\?
M0`!!5T%6055!5%532(T=`1D``$B#[$AF#V\%HU<``&1(BP0E*````$B)1"0X
M,<`QP$B-;"0,#RE$)!!F#V\%CU<``&:)1"0P#RE$)"`/'T0``#'`2(GN2(G?
MZ$/U__](A<!T/DB+!<=W``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``
M````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T==!@``&8/'X0``````#'`
M2(GN2(G?Z./T__](A<!T/DB+!6=W``!(8U0D#$B+`$B-!-!(BU`(2(D02(72
M=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T='!@``&8/'X0`
M`````#'`2(GN2(G?Z(/T__](A<!T/DB+!0=W``!(8U0D#$B+`$B-!-!(BU`(
M2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=Q1<`
M`&8/'X0``````#'`2(GN2(G?Z"/T__](A<!T/DB+!:=V``!(8U0D#$B+`$B-
M!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M3(TE;!<``&8/'X0``````#'`2(GN3(GGZ,/S__](A<!T/DB+!4=V``!(8U0D
M#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV
M9@\?1```2(T='!<``&8/'X0``````#'`2(GN2(G?Z&/S__](A<!T/DB+!>=U
M``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(
MA=)U\.NV9@\?1```3(TM<18``&8/'X0``````#'`2(GN3(GOZ`/S__](A<!T
M/DB+!8=U``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#
MP`A(B1!(A=)U\.NV9@\?1```3(T]:!8``&8/'X0``````#'`2(GN3(G_Z*/R
M__](A<!T/DB+!2=U``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````
M2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TU$A8``&8/'X0``````#'`2(GN
M3(GWZ$/R__](A<!T/DB+!<=T``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/
M'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=O!4``&8/'X0`````
M`#'`2(GN2(G?Z./Q__](A<!T/DB+!6=T``!(8U0D#$B+`$B-!-!(BU`(2(D0
M2(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(T=^A0``&8/
M'X0``````#'`2(GN2(G?Z(/Q__](A<!T/DB+!0=T``!(8U0D#$B+`$B-!-!(
MBU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(GN
M2(T]`Q4``.@Q\?__2(G&2(7`=`I,B?<QP.C/]/__2(GN2(T]\Q0``#'`Z`[Q
M__](B<9(A<!T#DB-/>\4```QP.BH]/__2(GN2(T]Z10``#'`Z.?P__](B<9(
MA<!T.DR)[S'`Z(7T__\QP$B--?,4``!,B>?H=/3__TB+1"0X9$@K!"4H````
M=55(@\1(6UU!7$%=05Y!7\-(B>Y(C3VF%```,<#HE/#__TB)QDB%P'0,3(G_
M,<#H,O3__^NK2+A005)?0TQ%04@Y1"0A=9IF@7PD*4X]=9%(C70D*^O3Z!K6
M__]F+@\?A```````2(/L&&1(BP0E*````$B)1"0(BP4@=0``@_C_=!M(BU0D
M"&1(*Q0E*````'5"2(/$&,-F#Q]$``!(C70D!$B-/;L3```QP.@%\/__2(G"
M,<!(A=)T$@^V`CPP#Y7"A,`/E<`/ML`AT(D%RW0``.NNZ)S5__]F9BX/'X0`
M`````)!(@^P(Z,?5__^)Q^@PU/__2(7`=`-(BP!(@\0(PP\?`$%5051,C25*
M%```54B)_4R)YU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z'_O__](A<!T
M"(`X`$B)PW4R2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG,<!;74%<
M05WI]_+__P\?@`````!(B>Y(B<?H5=3__TB%P'0@2(M$)`AD2"L$)2@```!U
M=DB#Q!A;74%<05W##Q]$``!(B>_HJ-/__TB)WTF)Q>B=T___28U\!0+HT]+_
M_TB#[`A)B>B^`0```%-(Q\+_____2(G'28G%3(T-0!(``$B-#2$3```QP.@4
MU?__6%I(BT0D"&1(*P0E*````'4(3(GNZ4_____H9=3__P\?1```05=,C3WO
M$0``059!54%455-(@>RH@0``2(E\)`A(C5PD/$R)_TB)WF1(BP0E*````$B)
MA"28@0``2(T%MA$``$C'1"10`````$C'A"2H`````````$C'1"1P`````$B)
M1"1(2(T%'Q(``$B)A"2(````2(T%81(``$B)A"20````2(T%'A(``$B)A"28
M````2(T%2Q(``$B)A"2@````2(T%0!(``$B)1"1H,<#H[NW__TB%P'0,@#@`
M2(G%#X6U!```,<#H!O[__TB)Q4B%P`^$^@,``$B)[^ABTO__2(U\``'HF-'_
M_T0/MD4`28G&183`=#I-B?1,C2WP$0``D$4/ML!,B>=,B>F^`0```$C'PO__
M__\QP$B#Q0%)@\0"Z,O3__]$#[9%`$6$P'713(VD)(````!(C3U2$0``ZQ))
MBWPD"$F#Q`A(A?\/A#X!``!(B=XQP.A$[?__2(G%2(7`=-R`.`!TUTB)Q^AO
M[___A<!TRTB)[^C#TO__28G%2(7`#X0'`0``#Q^``````$R)[^BHT?__3(GW
M2(G%Z)W1__]$C:0%!`0``$UCY$R)Y^C*T/__059-B>B^`0```$B)Q4B-!3,1
M``!,C0T_$```2,?"_____U!(C0T4$0``2(GO,<#H!M/__[[``0``2(GOZ&G3
M__]!6$%9@_C_=1+H*]+__T2+"$&#^1$/A3,#``!,C;0DL````$B)[TR)]NAK
MTO__08G%A<`/A,````!(BT0D"$F)Z+X!````13'D2(T5:1$``$B+"$B+!1]O
M``!(BS@QP.C5S___2(N$))B!``!D2"L$)2@````/A<$(``!(@<2H@0``3(G@
M6UU!7$%=05Y!7\-F#Q^$``````!%,>1(C2T[$```ZQ</'T``26/$2(MLQ$!(
MA>UT.X!]``!T-4B)[T&#Q`'H(>[__X7`=-U(B>_H=='__TF)Q4B%P`^%N?[_
M_TECQ$B+;,1`2(7M=<D/'T``13'MZ:#^__^+A"3(````)0#P```]`$````^%
M*?___XN$),P```")1"00Z(G1__\Y1"00#X4/____BX0DR````"7_`0``/<`!
M```/A?C^__],B>?H0,___TB-/;L/``!(B=Y)B<0QP.A,Z___2(G'2(7`#X10
M`@``Z-O0__](B<9(BT0D"$B+..A[\O__2(G#2(7`#X0O`@``2(G?Z+?/__](
MB<*#^`-^/TB82(TU;0\``$B)5"002(U\`_SHQ]#__X7`=2-(BU0D$(/Z!`^$
M#P8``(U"^TB8@#P#+P^$``8``&8/'T0``#'`Z'GZ__^%P'46,?9(B=_HR\__
M_XE$)!"%P`^%S`$``$B--<\.``!(C3U0#@``,<#H2N[__TB-'3@/``!,C34:
M#P``Z.?.__]32,?"_____TF)Z%!,C0WD#0``O@$```!,B>=(C0WE#@``,<#H
MKM#__UA:ZTQF+@\?A```````Z-O/__^#.!%U2NBASO__08/%`4B#[`A)B>A3
M3(T-G@T``$R)\;X!````055(Q\+_____3(GG4#'`Z&+0__](@\0@OL`!``!,
MB>?HP=#__X/X_W2L2(GOZ(3.__],B?],B>8QP.B7[?__3(GGZ"_Z___IE?W_
M_V8N#Q^$``````!(C3WR#0``13'DZQ$/'T``26/$2(M\Q&!(A?]T.4B)WC'`
M08/$`>BEZ?__2(7`=."`.`!TVTB)Q^@SS___2(G%2(7`#X6]^___26/$2(M\
MQ&!(A?]UQ[\-````2(TMG`T``.A)S?__0;A3````28G&Z;#[__](BT0D"$F)
MZ+X!````13'D2(T5%`X``$B+"$B+!0IL``!(BS@QP.C`S/__Z>;\__\/'P!(
MB<?H</G__TB+A"28@0``9$@K!"4H````#X6<!0``2('$J($``$B)[UM=05Q!
M74%>05_ID,[__TB+1"0(2(L8Z<3]__^Z`@```$C'QN[___^)QXG#Z/[.__](
MC80DD`$``+H&````B=](B<9(B40D".ARS/__@+PDD`$```!U#H"\))$!``!#
M#X2D!```BWPD$#'2,?;HO<[__[B)J\WO2,>$)+`````!(T5G2(F$)+@```!(
M+8O.$E=(B80DP````$@%\@08*TB)A"30````2(V$).@```!(QX0DR````'94
M,A!(QX0DV`````````!(QX0DX`````````#'A"0H`0```````$B)1"0H#Q]`
M`$B+="0(BWPD$+H`@```Z,7+__](B<%!B<"%P`^.9P$``$B+O"38````2(N4
M).````!(8\%(BUPD"(TTST@Y_DB)M"38````2(/2`$C!Z!U(`=!(8Y0D*`$`
M`$B)A"3@````A=(/A:X```!!@_@_#XX=`P``08U`P(E$)"3!Z`9$C6@!B40D
M&$G!Y09)`=UF+@\?A```````\P]O"_,/;U,03(GW2(/#0/,/;UO@\P]O8_`/
M$8PDZ`````\1E"3X````#Q&<)`@!```/$:0D&`$``.@1T?__3#GK=;R+1"08
M1(M$)"3!X`9!*<!(BWPD*$ECT+E(````3(GN1(E$)!CH8\O__T2+1"081(F$
M)"@!``#IZ?[__Y!!N4````")R$B+="0(2(E,)!A!*=%!.<E!#T[!2&/82(M$
M)"A(C3P02(G:Z'#-__^+A"0H`0``2(M,)!@!V(/X0(F$)"@!```/A9K^__]!
MB<A,B?=!*=A(`UPD"$2)1"08Z&K0__]$BT0D&.GB_O__BWPD$.CGR?__2(N$
M)-@```"+G"38````1(NL).````!(P>@##\N#X#]!#\V-2`%(F,:$!.@```"`
M@_DX#X[/`0``ND````!(8_%(`W0D*"G*=`\QP(G!@\`!Q@0.`#G0<O-,B??H
M]L___V8/[\!(QX0D&`$````````/$80DZ`````\1A"3X````#Q&$)`@!``!,
MB?=$B:PD(`$``$R-M"1!`0``3(TM,PH``(F<)"0!``#HJ,___TB+A"2P````
M#[>4)+````!)B<!(P>@0B(0D00$``&;!P@A)P>@8BX0DN````&:)E"1"`0``
M#\B)A"1$`0``BX0DP`````_(B80D2`$``(N$),@````/R(F$)$P!``"+A"30
M````#\B)A"10`0``2(V$)&`!``!(B40D$$B)PTB-A"2(`0``2(E$)`CK"P\?
M`$4/M@9)@\8!2(G?10^VP$R)Z;X!````2,?"_____S'`2(/#`NAOR___2#E<
M)`AUT$B-!;8)``#&A"2(`0```%#_="082(T-;@D``$F)Z$R)YS'`O@$```!,
MC0U9"```2,?"_____^@MR___65[IVOK__TB+1"0(2(M0"$B%T@^$]/G__TB)
MUTB)5"0(Z%?)__](@_@##X;=^?__2(M4)`A(C34-"0``2(U\`OSH9\K__TB+
M5"0(A<!(#T3:Z;?Y__])B=WI4OW__TB+1"0HNC@````Q_RG*2&/)2`'(@_H(
M<R[VP@0/A=T```"%T@^$5_[__\8``/;"`@^$2_[__S'_9HE\$/[I/_[__P\?
M1```B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"#_[_
M_X/B^#'`B<:#P`A(B3PQ.=!R\^GX_?__@+PDD@$``$$/A4[[__^`O"23`0``
M0P^%0/O__X"\))0!``!(#X4R^___@+PDE0$``$4/A23[__]$BW0D$+H"````
M2,?&QO___T2)]^C5R?__2(M<)`BZ*0```$2)]TB)WNA0Q___2(T%+@@``%!3
MZ7[^__]FD,<``````,=$$/P`````Z6_]___H*,G__P\?A```````05=!5D%5
M05154TB#["AD2(L$)2@```!(B40D&#'`9$B+!"4`````2`,%ZF4``$B-/;X&
M``!(BR@/MH6P````B(6Q````2(U$)!1(B40D"$B)QC'`Z`?C__](A<!T"8`X
M,0^$Z0(``#'`Z%+M__]D2(L$)0````!(`P6:90``2(LHN0L```"Z`0```$B-
M-6T'``!(B>_HUL;__TB%P`^$S@```$B+0!"#/>)W```!3(MH*`^.N0```#';
MZU$/'T``)0!!(``]`$$```^$B````$F+/KD"````,=+H4<G__TB)QDB+!9]W
M``!)8]1(BSS0Z#O(__]!B<"+!9)W``!%A<!U8X/%`D2)XSG%?5ED2(L$)0``
M``!(`P7[9```3&/[,<E,B>Y,B?J)W42-8P%(BSA)B<;H=\?__TB%P'0B2(LP
MBT8,B<*!X@`$(`"!^@`$```/A6C___](BW80ZX1FD(L%*G<``(U0_SG:#X1O
M`0``9$B+!"4`````2`,%EV0``+D#````N@$```!(C35R!@``2(LX2(G%Z-/%
M__](B<-(A<!T*$B+0!!(BWT`2(T54@8``$B+,.CDQ?__2(M#$$B+,/9&#D`/
MA:H!``!D2(L$)0````!(`P4[9```N0,```"Z`0```$B--1T&``!(BSA(B<7H
M=\7__TB)PTB%P'0O2(MT)`A(C3VT!```,<#H3.'__TB)PDB+0Q!(A=(/A#P!
M``!(BS!(BWT`Z'#%__]D2(L$)0````!(`P788P``N@$```!(C37!!0``2(LX
M2(G#Z$G$__](BSM(C17!!0``2(G&Z#?%__](BP-(BW0D"$B-/4`$``#&@+$`
M````,<#HVN#__TB)!0MV``!)B<1(A<`/A(<```"^P`$``$R)Y^AZQ___C5`!
M@_H!=@F#^!$/A=,```!(BT0D&&1(*P0E*`````^%N@```$B#Q"A;74%<05U!
M7D%?PV8/'T0``(/X`0^.B/[__[L!````9I!D2(L$)0````!(`P488P``3(GN
M@\,!2(LXZ%+$__\Y'7QU``!_VNE6_O__#Q]$``!(BSUA=0``Z)3Q__](B05E
M=0``28G$2(7`#X5:____2(T]@@4``#'`Z"/&__\/'P"`>`$`#X0G_?__Z0C]
M__^02(L5(74``$B+.$B+,NB^XO__Z;G^__](BWT`Z)#%___I2/[__^B6Q?__
MB<%(BP7U=```3(GB2(T]4P4``$B+,#'`Z,G%__]F#Q^$``````!!5%5(B?U(
M@^P(Z"'I__](B<?HZ>C__TF)Q#'`Z#_O__^%P'0C2(7M=!Z`?0``=!BZ!```
M`$B--=$#``!,B>?H/,/__X7`=`A(@\0(74%<PTB#Q`A(B>]=05SI(>#__Y#S
M#Q[Z2(L-)60``.GPPO__\P\>^DB#[`A(@\0(PP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$;
M`SO4````&0```."`__\8`0``H(3__R`&``"@AO__\````-"&__\$`0``D(?_
M_T`!``#`G?__D`$``)">___<`0```*#__R`"``"0H/__1`(``'"A__^``@``
MP*/__\P"````I/__Y`(``$"D__\``P```*7__S0#```0I?__2`,``!"G__^H
M`P``0*?__[P#```@J/__[`,``'"M__\\!```\*W__U@$```0KO__<`0``""O
M___,!```8+K__Z`%```0OO__[`4``'"^__]0!@```````!0``````````7I2
M``%X$`$;#`<(D`$``!`````<````J(7__R8`````1`<0$````#````#$A?__
M!0`````````D````1````,!____``P````X01@X82@\+=PB``#\:.RHS)"(`
M````3````&P```!(AO__,!8```!"#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P='#M`%`P@6"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````O```
M`"B<___-`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L
M"@XX1`XP00XH0@X@0@X80@X00@X(20L`0`````@!``"LG/__;`$```!"#A".
M`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+
M"P`@````3`$``-B=__^#`````$$.$(8"2@ZP`0)Q"@X000X(00LX````<`$`
M`$2>___=`````$(.$(X"1PX8C0-"#B",!$0.*(8%40[`(`*H"@XH00X@0@X8
M0@X00@X(00M(````K`$``.B>__]!`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9$#CB#!T<.8`,5`0H..$$.,$$.*$(.($(.&$(.$$(."$4+%````/@!
M``#LH/__-0````!$#A!L#@@`&````!`"```4H?__0`````!!#A"#`F8."```
M`#`````L`@``.*'__[\`````0@X0C`)!#AB&`T$.((,$1P[`0`*G"@X@1`X8
M00X00@X(00L0````8`(``,2A__\%`````````%P```!T`@``P*'___(!````
M0@X0CP)"#AB.`T4.((T$0@XHC`5!#C"&!DL..(,'1PZ`(@)D"@XX00XP00XH
M0@X@0@X80@X00@X(1`L"GPZ((DX.D"):#H@B00Z`(@```!````#4`@``8*/_
M_R4`````````+````.@"``!\H___W`````!*#A"&`@)B"L8."$P+>0H."$<+
M2`K&#@A%"TL.",8`3````!@#```LI/__1@4```!"#A"/`D(.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P=+#H`!`]L$"@XX00XP00XH0@X@0@X80@X00@X(00L`
M```8````:`,``"RI__]T`````$0.(&T*#@A'"P``%````(0#``"0J?__'0``
M``!$#A!8#@@`6````)P#``"8J?__"P$```!"#A"-`D(.&(P#2`X@A@1'#BB#
M!40.0`)""@XH1@X@00X80@X00@X(3`MD"@XH00X@00X80@X00@X(1@MA#DA)
M#E!C#DA!#D````#0````^`,``$RJ__\X"P```$(.$(\"20X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T<.X(,"`Z`!#NB#`F$.\(,"8`[H@P)"#N"#`@)^"@XX
M1`XP00XH0@X@0@X80@X00@X(2@L#B@$.Z(,"2P[P@P)>#NB#`D$.X(,"8P[H
M@P)$#O"#`E$.^(,"2PZ`A`)+#N"#`@,,`0H..$0.,$$.*$(.($(.&$(.$$(.
M"$4+`^@##NB#`D0.\(,":`[H@P)!#N"#`@-3`0H.Z(,"00[P@P)'"P```$@`
M``#,!```N+3__Z<#````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'
M1`Y@`\$""@XX00XP00XH0@X@0@X80@X00@X(1PLP````&`4``!RX__]?````
M`$(.$(P"00X8A@-'#B`"0@H.&$$.$$(."$$+1`X81`X00@X(+````$P%``!X
M?O__``(```!"#A",`D$.&(8#1`Y0`Y\!"@X81`X00@X(00L`````$````'P%
M```8N/__$```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#`)D```````)`F0````````0`````````4`P``````
M``$`````````)@,````````!`````````#`#`````````0`````````Z`P``
M``````$`````````3P,````````/`````````,`$````````#```````````
M($````````T`````````P%U````````9`````````&"]0```````&P``````
M```(`````````!H`````````:+U````````<``````````@`````````]?[_
M;P````#``T````````4`````````4`U````````&`````````(`$0```````
M"@````````#[!`````````L`````````&``````````5````````````````
M`````P````````#HOT````````(`````````B`4````````4``````````<`
M````````%P````````"P%$````````<`````````J!-````````(````````
M``@!````````"0`````````8`````````/[__V\`````"!-```````#___]O
M``````(`````````\/__;P````!,$D``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!PO4``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0```````MB-```````#&(T```````-8C0```````````````````````
M`````/____\`````V&)```````!'0T,Z("A03$0M3&EN=7@I(#$Q+C,N,"`R
M,#(R,#0R,2`H<F5L96%S92D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````````````````````````````````````````````"P````$````"
M`````````!@#0```````&`,````````<`````````````````````0``````
M`````````````!,````'`````@`````````X`T```````#@#````````0```
M``````````````````@````````````````````F````!P````(`````````
M>`-```````!X`P```````"0````````````````````$````````````````
M````.0````<````"`````````)P#0```````G`,````````@````````````
M````````!````````````````````$<```#V__]O`@````````#``T``````
M`,`#````````O``````````&``````````@```````````````````!1````
M"P````(`````````@`1```````"`!````````-`(````````!P````$````(
M`````````!@`````````60````,````"`````````%`-0```````4`T`````
M``#[!````````````````````0```````````````````&$```#___]O`@``
M``````!,$D```````$P2````````O``````````&``````````(`````````
M`@````````!N````_O__;P(`````````"!-````````($P```````*``````
M````!P````(````(````````````````````?0````0````"`````````*@3
M0```````J!,````````(`0````````8`````````"``````````8````````
M`(<````$````0@````````"P%$```````+`4````````B`4````````&````
M%P````@`````````&`````````"1`````0````8``````````"!`````````
M(````````!L````````````````````$````````````````````C`````$`
M```&`````````"`@0```````("````````#``P``````````````````$```
M```````0`````````)<````!````!@````````#@(T```````.`C````````
MX#D``````````````````!````````````````````"=`````0````8`````
M````P%U```````#`70````````T````````````````````$````````````
M````````HP````$````"``````````!@0````````&````````!`/P``````
M````````````$````````````````````*L````!`````@````````!`GT``
M`````$"?````````U`````````````````````0```````````````````"Y
M`````0````(`````````&*!````````8H````````)`%````````````````
M```(````````````````````PP````X````#`````````&"]0```````8*T`
M```````(````````````````````"``````````(`````````,\````/````
M`P````````!HO4```````&BM````````"`````````````````````@`````
M````"`````````#;````!@````,`````````<+U```````!PK0```````"`"
M````````!P`````````(`````````!``````````Y`````$````#````````
M`)"_0```````D*\```````!8````````````````````"``````````(````
M`````.D````!`````P````````#HOT```````.BO````````\`$`````````
M``````````@`````````"`````````#R`````0````,`````````V,%`````
M``#8L0```````"`````````````````````(````````````````````^```
M``@````#``````````#"0```````^+$```````!($```````````````````
M(````````````````````/T````!````,````````````````````/BQ````
M````*P````````````````````$``````````0`````````!`````P``````
M```````````````````CL@````````8!```````````````````!````````
)````````````
